Analyse écoconception pour le site {{ site }}

# ⬆️ Synthèse

Le score ecoindex

L'ecoindex est un indicateur développé par le collectif numérique responsable. Il permet d'analyser une page html et d'en déduire une score en se basant sur trois critères physiques d'une page web.

Le calcul de l'ecoindex permet de déduire un indicateur normé (de A à G) permettant de décrire l'empreinte environnementale d'une page.

Cette synthèse est basée sur l'analyse de {{ nb_page }} pages du site internet {{ site }}

Plus d'infos sur Ecoindex.fr

{{ summary }}

# ⬆️ Top 10

## ✔️ Meilleures pages

{{ best}}

## ❌️ Moins bonnes pages

{{ worst}}

# ⬆️ Indicateurs écoindex

## Nombre de requêtes

Le nombre de requêtes HTTP donne une bonne idée de la charge serveur. Pour le dire vite et de façon caricaturale, plus le nombre de requêtes est important pour une même page et plus il faudra de serveurs pour servir cette page.

## Taille des pages

Le poids des données transférées (Ko) témoigne des efforts à faire pour transporter la page jusqu’au navigateur. Dans cette première version, nous considérons que la connexion est de type Wi-Fi via ADSL. Mais dans la prochaine version nous prendrons en compte différents types de connexions, notamment 4G. En effet, une connexion 4G nécessite jusqu’à 23 fois plus d’énergie pour transporter la même quantité de données qu’une connexion ADSL.

## Nombre d'éléments de la page

Le nombre d’éléments du DOM témoigne de la complexité du site et donc, a priori, des efforts à faire par le navigateur pour afficher la page. Plus le site est complexe et plus il faut de puissance (notamment CPU) pour l’afficher. Et plus on contribue à raccourcir la durée de vie de l’ordinateur sur lequel il s’exécute. A l’inverse, un site particulièrement simple et léger contribue à allonger la durée de vie de l’équipement car il nécessite peu de mémoire et un “petit” processeur.

# ⬆️ Toutes les données

{{ all_data }}